package Tie::Tools;

use strict;
use warnings;
use vars qw($VERSION);

$VERSION = '1.10';

1;

__END__

=pod

=begin markdown

[![CPAN version](https://badge.fury.io/pl/Tie-Tools.svg)](http://badge.fury.io/pl/Tie-Tools)
[![Build Status](https://travis-ci.org/jonasbn/Tie-Tools.svg?branch=master)](https://travis-ci.org/jonasbn/Tie-Tools)
[![Coverage Status](https://coveralls.io/repos/jonasbn/Tie-Tools/badge.png)](https://coveralls.io/r/jonasbn/Tie-Tools)

=end markdown

=head1 NAME

Tie::Tools - a collection of tying tools

=head1 DESCRIPTION

Tie::Tools consist of several modules each in their own namespace.

=over 4

=item * L<Tie::DeepTied>

=item * L<Tie::Depth>

=item * L<Tie::Func>

=item * L<Tie::NormalArray>

=item * L<Tie::Parent>

=back

=cut

=head1 LICENSE

Tie::Tools is free software and is released under the Artistic License.
See <http://www.perl.com/language/misc/Artistic.html> for details.

=head1 AUTHOR

This is originally the work of Ariel Brosh, a member of Israel.pm and
author of several contributions to CPAN. He has unfortunately passed
away and have left behind several Perl modules where this is just one
of them.

I volunteered to contribute further to the development of the modules,
but it is still kept under the name of Ariel Brosh - the original
author.

Jonas B. Nielsen <jonasbn@cpan.org>

=head1 ACKNOWLEDGEMENTS

=over

=item * patch from Brian Dowling resulting in release 1.06

=back

=cut
